clear all;
clc;
% Initialize the LMS filter with a length of 11 and step size of 0.05.
FrameSize = 100; NIter = 10;
lmsfilt2 = dsp.LMSFilter('Length',11,'Method','Normalized LMS', ...
    'StepSize',0.05);
firfilt2 = dsp.FIRFilter('Numerator', fir1(10,[.5, .75]));
sinewave = dsp.SineWave('Frequency',0.01, ...
    'SampleRate',1,'SamplesPerFrame',FrameSize);
TS = dsp.TimeScope('TimeSpan',FrameSize*NIter,'TimeUnits','Seconds',...
    'YLimits',[-3 3],'BufferLength',2*FrameSize*NIter, ...
    'ShowLegend',true,'ChannelNames', ...
    {'Noisy signal', 'Filtered signal'});
%%
% Pass the noisy input signal into the LMS filter and view the filtered 
% output in the time scope.
for k = 1:NIter
    x = randn(FrameSize,1);       % Input signal
    d = firfilt2(x) + sinewave(); % Noise + Signal
    [y,e,w] = lmsfilt2(x,d);
    TS([d,e]);          % Noisy = channel 1; Filtered = channel 2
end
FrameSize = 15000;
lmsfilt3 = dsp.LMSFilter('Length',63,'Method','LMS', ...
    'StepSize',0.001,'LeakageFactor',0.99999, ...
    'WeightsOutput','All'); % full Weights history

w_actual = fir1(64,[0.5 0.75]);
firfilt3 = dsp.FIRFilter('Numerator',w_actual);
sinewave = dsp.SineWave('Frequency',0.01, ...
    'SampleRate',1,'SamplesPerFrame',FrameSize);

TS = dsp.TimeScope('TimeSpan',FrameSize,'TimeUnits','Seconds', ...
    'YLimits',[-0.25 0.75],'BufferLength',2*FrameSize, ...
    'ShowLegend',true,'ChannelNames', ...
    {'Coeff 33 Estimate','Coeff 34 Estimate','Coeff 35 Estimate', ...
    'Coeff 33 Actual','Coeff 34 Actual','Coeff 35 Actual'});
%%
% Run one frame and output the full adaptive weights history, |w|.
x = randn(FrameSize,1);       % Input signal
d = firfilt3(x) + sinewave(); % Noise + Signal
[~,~,w] = lmsfilt3(x,d);
.
idxBeg = 33; 
idxEnd = 35;
TS([w(:,idxBeg:idxEnd), repmat(w_actual(idxBeg:idxEnd),FrameSize,1)]);

%% System Identification Using LMS Filter
%%
% *Note*: This example runs only in R2016b or later. If you are using an
% earlier release, replace each call to the function with the equivalent
% |step| syntax. For example, myObject(x) becomes step(myObject,x).
%%
lms1 = dsp.LMSFilter(11,'StepSize',0.01);
filt = dsp.FIRFilter; % System to be identified
filt.Numerator = fir1(10,.25);
x = randn(1000,1); % input signal

d = filt(x) + 0.01*randn(1000,1); % desired signal
[y,e,w] = lms1(x,d);

subplot(2,1,1); 
plot(1:1000, [d,y,e]);
title('System Identification of an FIR filter');
legend('Desired', 'Output', 'Error');
xlabel('time index'); 
ylabel('signal value');
subplot(2,1,2); 
stem([filt.Numerator.',w]);
legend('Actual','Estimated'); 
xlabel('coefficient #'); 
ylabel('coefficient value'); 